/*
 * Copyright 2003-2007 Sun Microsystems, Inc.  All Rights Reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
 * CA 95054 USA or visit www.sun.com if you need additional information or
 * have any questions.
 */

package sun.java2d.xr;

import static sun.java2d.loops.CompositeType.SrcNoEa;
import static sun.java2d.loops.CompositeType.SrcOver;
import static sun.java2d.loops.SurfaceType.IntArgbPre;
import static sun.java2d.loops.SurfaceType.IntRgb;

import java.awt.Composite;

import sun.awt.*;
import sun.java2d.*;
import sun.java2d.loops.*;
import sun.java2d.pipe.Region;

/**
 * For XRender there is no "blit", everything is just a fill with Repeat of Not.
 * So basically this just quite the same as MaskFill.
 * @author Clemens Eisserer
 */
public class XRMaskBlit extends MaskBlit {
    static void register() {
	GraphicsPrimitive[] primitives = {
		new XRMaskBlit(IntArgbPre, SrcOver, IntArgbPre),
		new XRMaskBlit(IntRgb, SrcOver, IntRgb),
		new XRMaskBlit(IntArgbPre, SrcNoEa, IntRgb),
		new XRMaskBlit(IntRgb, SrcNoEa, IntArgbPre) 
		};
	GraphicsPrimitiveMgr.register(primitives);
    }

    public XRMaskBlit(SurfaceType srcType, CompositeType compType,
	    SurfaceType dstType) {
	super(srcType, CompositeType.AnyAlpha, dstType);
    }

    protected native void maskBlit(long srcXsdo, long dstxsdo, int srcx,
	    int srcy, int dstx, int dsty, int w, int h, int maskoff,
	    int maskscan, int masklen, byte[] mask);

    public void MaskBlit(SurfaceData src, SurfaceData dst, Composite comp,
	    Region clip, int srcx, int srcy, int dstx, int dsty, int width,
	    int height, byte[] mask, int maskoff, int maskscan) {
	if (width <= 0 || height <= 0) {
	    return;
	}

	try {
	    SunToolkit.awtLock();

	    XRSurfaceData x11sd = (XRSurfaceData) src;
	    x11sd.validateAsSource(null, XRUtils.RepeatNone);

	    XRSurfaceData x11dst = (XRSurfaceData) dst;
	    x11dst.validate(clip, comp, null, null, null, 0);

	    maskBlit(src.getNativeOps(), dst.getNativeOps(), srcx, srcy, dstx,
		    dsty, width, height, maskoff, maskscan,
		    mask != null ? mask.length : 0, mask);
	} finally {
	    SunToolkit.awtUnlock();
	}
    }
}
